@@ -10,7 +10,7 @@ void F77_NAME(ngloglik)(double *yt, int *ymiss, int *timevar, double *zt, double
 void F77_NAME(isample)(double *yt, int *ymiss, int *timevar, double *zt, double *tt, double *rtv, double *qt, double *a1, double *p1,double *p1inf, double *u, int *dist, int *p, int *n, int *m, int *r, double *theta, int *maxiter,int *rankp,double *convtol, int *nnd,int *nsim, double *epsplus,double *etaplus,double *aplus1,double *c,double *tol,int *info,int *antithetics,double *w,double *sim,int *nd,int *ndl, int *simwhat, int *simdim);
 void F77_NAME(zalpha)(int *timevar, double *zt, int *alpha, double *theta, int *p, int *m, int *n, int *nsim, int *m2, int *states);
 void F77_NAME(varmeanw)(double *x,double *w,int *m,int *n,int *k,double *meanx,double *varx,int *var);
-void F77_NAME(artransform)(double *u, double *phi, int *p);
+void F77_NAME(artransform)(double *phi, int *p);
 void F77_NAME(simfilter)(int *ymiss,int *timevar, double *yt, double *zt, double *ht, double *tt, double *rtv, double *qt, double *a1, double *p1, double *p1inf, int *nnd, int *nsim, double *epsplus, double *etaplus, double *aplus1, int *p, int *n, int *m, int *r, int *info,int *rankp, double *tol, int *nd, int *ndl, double *sim, double *c, int *simwhat, int *simdim, int *antithetics);
 void F77_NAME(ngfilter)(double *yt, int *ymiss, int *timevar, double *zt, double *tt, double *rtv, double *qt, double *a1, double *p1,double *p1inf, double *u, double *theta,int *dist, int *p,int *n, int *m, int *r, int *rankp, int *nnd,int *nsim,double *epsplus,double *etaplus,double *aplus1,double *c,double *tol,int *info, int *maxiter,double *convtol,int *nd,int *ndl,double *alphahat,double *alphavar,double *thetahat,double *thetavar,double *yhat,double *yvar,int *smootha, int *smooths, int *smoothy);
 void F77_NAME(isamplefilter)(double *yt, int *ymiss, int *timevar, double *zt, double *tt, double *rtv, double *qt, double *a1, double *p1,double *p1inf, double *u, int *dist, int *p, int *n, int *m, int *r, double *theta, int *maxiter,int *rankp,double *convtol, int *nnd,int *nsim, double *epsplus,double *etaplus,double *aplus1,double *c,double *tol,int *info, int *antithetics, double *w,double *sim, int *nd,int *ndl, int *simwhat, int *simdim);
